Index: apps/app_voicemail.c
===================================================================
--- apps/app_voicemail.c	(revision 47782)
+++ apps/app_voicemail.c	(working copy)
@@ -402,6 +402,11 @@
 
 static char ext_pass_cmd[128];
 
+/* Signal password changes to be handled internally and/or externally */
+/* One or both should probably be true, though I guess it wouldn't be mandatory */
+static int pwchangeexternal = 0;
+static int pwchangeinternal = 1;
+
 #if ODBC_STORAGE
 #define tdesc "Comedian Mail (Voicemail System) with ODBC Storage"
 #elif IMAP_STORAGE
@@ -5741,10 +5746,11 @@
 		if (++tries == 3)
 			return -1;
 	}
-	if (ast_strlen_zero(ext_pass_cmd)) 
-		vm_change_password(vmu,newpassword);
-	else 
-		vm_change_password_shell(vmu,newpassword);
+	if (pwchangeinternal)
+		vm_change_password(vmu, newpassword);
+	if (pwchangeexternal && !ast_strlen_zero(ext_pass_cmd))
+		vm_change_password_shell(vmu, newpassword);
+
 	if (option_debug)
 		ast_log(LOG_DEBUG,"User %s set password to %s of length %d\n",vms->username,newpassword,(int)strlen(newpassword));
 	cmd = ast_play_and_wait(chan, vm_passchanged);
@@ -5844,10 +5850,11 @@
 				cmd = ast_play_and_wait(chan, vm_mismatch);
 				break;
 			}
-			if (ast_strlen_zero(ext_pass_cmd)) 
-				vm_change_password(vmu,newpassword);
-			else 
-				vm_change_password_shell(vmu,newpassword);
+			if (pwchangeinternal)
+				vm_change_password(vmu, newpassword);
+			if (pwchangeexternal && !ast_strlen_zero(ext_pass_cmd))
+				vm_change_password_shell(vmu, newpassword);
+
 			if (option_debug)
 				ast_log(LOG_DEBUG,"User %s set password to %s of length %d\n",vms->username,newpassword,(int)strlen(newpassword));
 			cmd = ast_play_and_wait(chan, vm_passchanged);
@@ -7173,10 +7180,18 @@
 			ast_copy_string(emaildateformat, emaildateformatstr, sizeof(emaildateformat));
 		}
 
-		/* External password changing command */
+		/* External only password changing command */
 		if ((extpc = ast_variable_retrieve(cfg, "general", "externpass"))) {
 			ast_copy_string(ext_pass_cmd,extpc,sizeof(ext_pass_cmd));
+			pwchangeexternal = 1;
+			pwchangeinternal = 0;
 		}
+		/* Internal and external password changing command */
+		if ((extpc = ast_variable_retrieve(cfg, "general", "externpassnotify"))) {
+			ast_copy_string(ext_pass_cmd,extpc,sizeof(ext_pass_cmd));
+			pwchangeexternal = 1;
+			pwchangeinternal = 1;
+		}
 #ifdef IMAP_STORAGE
 		/* IMAP server address */
 		if ((imap_server = ast_variable_retrieve(cfg, "general", "imapserver"))) {
Index: configs/voicemail.conf.sample
===================================================================
--- configs/voicemail.conf.sample	(revision 47782)
+++ configs/voicemail.conf.sample	(working copy)
@@ -66,7 +66,11 @@
 
 ; If you need to have an external program, i.e. /usr/bin/myapp
 ; called when a voicemail password is changed, uncomment this:
+; Note: If this is set, the password will NOT be changed in voicemail.conf
+; If you would like to also change the password in voicemail.conf, use
+; the externpassnotify option below.
 ;externpass=/usr/bin/myapp
+;externpassnotify=/usr/bin/myapp
 ; For the directory, you can override the intro file if you want
 ;directoryintro=dir-intro
 ; The character set for voicemail messages can be specified here
